@@ -4,21 +4,21 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.26';
+our $VERSION = '1.28';
 
 my %jamo2prim = (
-    '1100', 0x3BF5,   '1101', 0x3BF6,   '1102', 0x3BF7,   '1103', 0x3BF8,
-    '1105', 0x3BFA,   '1106', 0x3BFB,   '1107', 0x3BFC,   '1109', 0x3BFE,
-    '110A', 0x3BFF,   '110B', 0x3C00,   '110C', 0x3C01,   '110E', 0x3C03,
-    '110F', 0x3C04,   '1110', 0x3C05,   '1111', 0x3C06,   '1112', 0x3C07,
-    '1161', 0x3C73,   '1162', 0x3C74,   '1163', 0x3C75,   '1165', 0x3C77,
-    '1166', 0x3C78,   '1167', 0x3C79,   '1168', 0x3C7A,   '1169', 0x3C7B,
-    '116A', 0x3C7C,   '116B', 0x3C7D,   '116C', 0x3C7E,   '116D', 0x3C7F,
-    '116E', 0x3C80,   '116F', 0x3C81,   '1170', 0x3C82,   '1171', 0x3C83,
-    '1172', 0x3C84,   '1173', 0x3C85,   '1174', 0x3C86,   '1175', 0x3C87,
-    '11A8', 0x3CD1,   '11AB', 0x3CD4,   '11AF', 0x3CD8,   '11B7', 0x3CE0,
-    '11B8', 0x3CE1,   '11BC', 0x3CE5,   '11BD', 0x3CE6,
-); # for DUCET v9.0.0
+    '1100', 0x4011,   '1101', 0x4012,   '1102', 0x4013,   '1103', 0x4014,
+    '1105', 0x4016,   '1106', 0x4017,   '1107', 0x4018,   '1109', 0x401A,
+    '110A', 0x401B,   '110B', 0x401C,   '110C', 0x401D,   '110E', 0x401F,
+    '110F', 0x4020,   '1110', 0x4021,   '1111', 0x4022,   '1112', 0x4023,
+    '1161', 0x408F,   '1162', 0x4090,   '1163', 0x4091,   '1165', 0x4093,
+    '1166', 0x4094,   '1167', 0x4095,   '1168', 0x4096,   '1169', 0x4097,
+    '116A', 0x4098,   '116B', 0x4099,   '116C', 0x409A,   '116D', 0x409B,
+    '116E', 0x409C,   '116F', 0x409D,   '1170', 0x409E,   '1171', 0x409F,
+    '1172', 0x40A0,   '1173', 0x40A1,   '1174', 0x40A2,   '1175', 0x40A3,
+    '11A8', 0x40ED,   '11AB', 0x40F0,   '11AF', 0x40F4,   '11B7', 0x40FC,
+    '11B8', 0x40FD,   '11BC', 0x4101,   '11BD', 0x4102,
+); # for DUCET v12.1.0
 
 my(%u2e, $prim, $wt);
 while (<DATA>) {
