@@ -1,214 +1,214 @@
 use Unicode::Collate::CJK::Big5;
 +{
-   locale_version => 1.26,
+   locale_version => 1.28,
    overrideCJK => \&Unicode::Collate::CJK::Big5::weightBig5,
-   entry => <<'ENTRY', # for DUCET v9.0.0
-0101      ; [.1C47.001C.0002] # LATIN SMALL LETTER A WITH MACRON
-0061 0304 ; [.1C47.001C.0002] # LATIN SMALL LETTER A WITH MACRON
-0100      ; [.1C47.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
-0041 0304 ; [.1C47.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
-00E1      ; [.1C47.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-0061 0301 ; [.1C47.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-0061 0341 ; [.1C47.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-00C1      ; [.1C47.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-0041 0301 ; [.1C47.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-0041 0341 ; [.1C47.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-01CE      ; [.1C47.001E.0002] # LATIN SMALL LETTER A WITH CARON
-0061 030C ; [.1C47.001E.0002] # LATIN SMALL LETTER A WITH CARON
-01CD      ; [.1C47.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
-0041 030C ; [.1C47.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
-00E0      ; [.1C47.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-0061 0300 ; [.1C47.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-0061 0340 ; [.1C47.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-00C0      ; [.1C47.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0041 0300 ; [.1C47.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0041 0340 ; [.1C47.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0113      ; [.1CAA.001C.0002] # LATIN SMALL LETTER E WITH MACRON
-0065 0304 ; [.1CAA.001C.0002] # LATIN SMALL LETTER E WITH MACRON
-0112      ; [.1CAA.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
-0045 0304 ; [.1CAA.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
-00E9      ; [.1CAA.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-0065 0301 ; [.1CAA.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-0065 0341 ; [.1CAA.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-00C9      ; [.1CAA.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-0045 0301 ; [.1CAA.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-0045 0341 ; [.1CAA.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-011B      ; [.1CAA.001E.0002] # LATIN SMALL LETTER E WITH CARON
-0065 030C ; [.1CAA.001E.0002] # LATIN SMALL LETTER E WITH CARON
-011A      ; [.1CAA.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
-0045 030C ; [.1CAA.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
-00E8      ; [.1CAA.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-0065 0300 ; [.1CAA.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-0065 0340 ; [.1CAA.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-00C8      ; [.1CAA.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-0045 0300 ; [.1CAA.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-0045 0340 ; [.1CAA.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-00EA 0304 ; [.1CAA.0021.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
-00CA 0304 ; [.1CAA.0021.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
-0065 0302 0304 ; [.1CAA.0021.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
-0045 0302 0304 ; [.1CAA.0021.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
-1EBF      ; [.1CAA.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-0065 0302 0301 ; [.1CAA.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-0065 0302 0341 ; [.1CAA.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-1EBE      ; [.1CAA.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-0045 0302 0301 ; [.1CAA.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-0045 0302 0341 ; [.1CAA.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-00EA 0301 ; [.1CAA.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
-00EA 0341 ; [.1CAA.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
-00CA 0301 ; [.1CAA.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
-00CA 0341 ; [.1CAA.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
-00EA 030C ; [.1CAA.0023.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
-00CA 030C ; [.1CAA.0023.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
-0065 0302 030C ; [.1CAA.0023.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
-0045 0302 030C ; [.1CAA.0023.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
-1EC1      ; [.1CAA.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-0065 0302 0300 ; [.1CAA.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-0065 0302 0340 ; [.1CAA.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-1EC0      ; [.1CAA.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-0045 0302 0300 ; [.1CAA.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-0045 0302 0340 ; [.1CAA.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-00EA 0300 ; [.1CAA.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
-00EA 0340 ; [.1CAA.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
-00CA 0300 ; [.1CAA.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
-00CA 0340 ; [.1CAA.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
-00EA      ; [.1CAA.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
-0065 0302 ; [.1CAA.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
-00CA      ; [.1CAA.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-0045 0302 ; [.1CAA.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-1EC5      ; [.1CAA.0025.0002][.0000.002D.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
-1EC4      ; [.1CAA.0025.0008][.0000.002D.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
-1EC3      ; [.1CAA.0025.0002][.0000.003B.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
-1EC2      ; [.1CAA.0025.0008][.0000.003B.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
-1EC7      ; [.1CAA.0025.0002][.0000.0042.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
-1EC6      ; [.1CAA.0025.0008][.0000.0042.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
-012B      ; [.1D32.001C.0002] # LATIN SMALL LETTER I WITH MACRON
-0069 0304 ; [.1D32.001C.0002] # LATIN SMALL LETTER I WITH MACRON
-012A      ; [.1D32.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
-0049 0304 ; [.1D32.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
-00ED      ; [.1D32.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-0069 0301 ; [.1D32.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-0069 0341 ; [.1D32.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-00CD      ; [.1D32.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-0049 0301 ; [.1D32.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-0049 0341 ; [.1D32.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-01D0      ; [.1D32.001E.0002] # LATIN SMALL LETTER I WITH CARON
-0069 030C ; [.1D32.001E.0002] # LATIN SMALL LETTER I WITH CARON
-01CF      ; [.1D32.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
-0049 030C ; [.1D32.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
-00EC      ; [.1D32.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-0069 0300 ; [.1D32.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-0069 0340 ; [.1D32.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-00CC      ; [.1D32.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-0049 0300 ; [.1D32.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-0049 0340 ; [.1D32.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-006D 0304 ; [.1DAA.001C.0002] # <LATIN SMALL LETTER M, COMBINING MACRON>
-004D 0304 ; [.1DAA.001C.0008] # <LATIN CAPITAL LETTER M, COMBINING MACRON>
-1E3F      ; [.1DAA.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-006D 0301 ; [.1DAA.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-006D 0341 ; [.1DAA.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-1E3E      ; [.1DAA.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-004D 0301 ; [.1DAA.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-004D 0341 ; [.1DAA.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-006D 030C ; [.1DAA.001E.0002] # <LATIN SMALL LETTER M, COMBINING CARON>
-004D 030C ; [.1DAA.001E.0008] # <LATIN CAPITAL LETTER M, COMBINING CARON>
-006D 0300 ; [.1DAA.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE ACCENT>
-006D 0340 ; [.1DAA.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE TONE MARK>
-004D 0300 ; [.1DAA.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE ACCENT>
-004D 0340 ; [.1DAA.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE TONE MARK>
-006E 0304 ; [.1DB9.001C.0002] # <LATIN SMALL LETTER N, COMBINING MACRON>
-004E 0304 ; [.1DB9.001C.0008] # <LATIN CAPITAL LETTER N, COMBINING MACRON>
-0144      ; [.1DB9.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-006E 0301 ; [.1DB9.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-006E 0341 ; [.1DB9.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-0143      ; [.1DB9.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-004E 0301 ; [.1DB9.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-004E 0341 ; [.1DB9.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-0148      ; [.1DB9.001E.0002] # LATIN SMALL LETTER N WITH CARON
-006E 030C ; [.1DB9.001E.0002] # LATIN SMALL LETTER N WITH CARON
-0147      ; [.1DB9.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
-004E 030C ; [.1DB9.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
-01F9      ; [.1DB9.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-006E 0300 ; [.1DB9.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-006E 0340 ; [.1DB9.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-01F8      ; [.1DB9.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-004E 0300 ; [.1DB9.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-004E 0340 ; [.1DB9.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-014D      ; [.1DDD.001C.0002] # LATIN SMALL LETTER O WITH MACRON
-006F 0304 ; [.1DDD.001C.0002] # LATIN SMALL LETTER O WITH MACRON
-014C      ; [.1DDD.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
-004F 0304 ; [.1DDD.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
-00F3      ; [.1DDD.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-006F 0301 ; [.1DDD.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-006F 0341 ; [.1DDD.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-00D3      ; [.1DDD.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-004F 0301 ; [.1DDD.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-004F 0341 ; [.1DDD.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-01D2      ; [.1DDD.001E.0002] # LATIN SMALL LETTER O WITH CARON
-006F 030C ; [.1DDD.001E.0002] # LATIN SMALL LETTER O WITH CARON
-01D1      ; [.1DDD.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
-004F 030C ; [.1DDD.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
-00F2      ; [.1DDD.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-006F 0300 ; [.1DDD.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-006F 0340 ; [.1DDD.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-00D2      ; [.1DDD.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-004F 0300 ; [.1DDD.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-004F 0340 ; [.1DDD.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-016B      ; [.1EB5.001C.0002] # LATIN SMALL LETTER U WITH MACRON
-0075 0304 ; [.1EB5.001C.0002] # LATIN SMALL LETTER U WITH MACRON
-016A      ; [.1EB5.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
-0055 0304 ; [.1EB5.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
-00FA      ; [.1EB5.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-0075 0301 ; [.1EB5.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-0075 0341 ; [.1EB5.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-00DA      ; [.1EB5.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-0055 0301 ; [.1EB5.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-0055 0341 ; [.1EB5.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-01D4      ; [.1EB5.001E.0002] # LATIN SMALL LETTER U WITH CARON
-0075 030C ; [.1EB5.001E.0002] # LATIN SMALL LETTER U WITH CARON
-01D3      ; [.1EB5.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
-0055 030C ; [.1EB5.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
-00F9      ; [.1EB5.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-0075 0300 ; [.1EB5.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-0075 0340 ; [.1EB5.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-00D9      ; [.1EB5.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-0055 0300 ; [.1EB5.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-0055 0340 ; [.1EB5.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-01D6      ; [.1EB5.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
-0075 0308 0304 ; [.1EB5.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
-01D5      ; [.1EB5.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
-0055 0308 0304 ; [.1EB5.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
-00FC 0304 ; [.1EB5.0021.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING MACRON>
-00DC 0304 ; [.1EB5.0021.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING MACRON>
-01D8      ; [.1EB5.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-0075 0308 0301 ; [.1EB5.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-0075 0308 0341 ; [.1EB5.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-01D7      ; [.1EB5.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-0055 0308 0301 ; [.1EB5.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-0055 0308 0341 ; [.1EB5.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-00FC 0301 ; [.1EB5.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
-00FC 0341 ; [.1EB5.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
-00DC 0301 ; [.1EB5.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
-00DC 0341 ; [.1EB5.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
-01DA      ; [.1EB5.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
-0075 0308 030C ; [.1EB5.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
-01D9      ; [.1EB5.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
-0055 0308 030C ; [.1EB5.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
-00FC 030C ; [.1EB5.0023.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING CARON>
-00DC 030C ; [.1EB5.0023.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING CARON>
-01DC      ; [.1EB5.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-0075 0308 0300 ; [.1EB5.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-0075 0308 0340 ; [.1EB5.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-01DB      ; [.1EB5.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-0055 0308 0300 ; [.1EB5.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-0055 0308 0340 ; [.1EB5.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-00FC 0300 ; [.1EB5.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
-00FC 0340 ; [.1EB5.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
-00DC 0300 ; [.1EB5.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
-00DC 0340 ; [.1EB5.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
-00FC      ; [.1EB5.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-0075 0308 ; [.1EB5.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-00DC      ; [.1EB5.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
-0055 0308 ; [.1EB5.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
+   entry => <<'ENTRY', # for DUCET v12.1.0
+0101      ; [.1E89.001C.0002] # LATIN SMALL LETTER A WITH MACRON
+0061 0304 ; [.1E89.001C.0002] # LATIN SMALL LETTER A WITH MACRON
+0100      ; [.1E89.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
+0041 0304 ; [.1E89.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
+00E1      ; [.1E89.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+0061 0301 ; [.1E89.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+0061 0341 ; [.1E89.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+00C1      ; [.1E89.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+0041 0301 ; [.1E89.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+0041 0341 ; [.1E89.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+01CE      ; [.1E89.001E.0002] # LATIN SMALL LETTER A WITH CARON
+0061 030C ; [.1E89.001E.0002] # LATIN SMALL LETTER A WITH CARON
+01CD      ; [.1E89.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
+0041 030C ; [.1E89.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
+00E0      ; [.1E89.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+0061 0300 ; [.1E89.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+0061 0340 ; [.1E89.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+00C0      ; [.1E89.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0041 0300 ; [.1E89.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0041 0340 ; [.1E89.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0113      ; [.1EED.001C.0002] # LATIN SMALL LETTER E WITH MACRON
+0065 0304 ; [.1EED.001C.0002] # LATIN SMALL LETTER E WITH MACRON
+0112      ; [.1EED.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
+0045 0304 ; [.1EED.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
+00E9      ; [.1EED.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+0065 0301 ; [.1EED.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+0065 0341 ; [.1EED.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+00C9      ; [.1EED.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+0045 0301 ; [.1EED.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+0045 0341 ; [.1EED.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+011B      ; [.1EED.001E.0002] # LATIN SMALL LETTER E WITH CARON
+0065 030C ; [.1EED.001E.0002] # LATIN SMALL LETTER E WITH CARON
+011A      ; [.1EED.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
+0045 030C ; [.1EED.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
+00E8      ; [.1EED.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+0065 0300 ; [.1EED.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+0065 0340 ; [.1EED.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+00C8      ; [.1EED.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+0045 0300 ; [.1EED.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+0045 0340 ; [.1EED.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+00EA 0304 ; [.1EED.0021.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
+00CA 0304 ; [.1EED.0021.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
+0065 0302 0304 ; [.1EED.0021.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
+0045 0302 0304 ; [.1EED.0021.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
+1EBF      ; [.1EED.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+0065 0302 0301 ; [.1EED.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+0065 0302 0341 ; [.1EED.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+1EBE      ; [.1EED.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+0045 0302 0301 ; [.1EED.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+0045 0302 0341 ; [.1EED.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+00EA 0301 ; [.1EED.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
+00EA 0341 ; [.1EED.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
+00CA 0301 ; [.1EED.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
+00CA 0341 ; [.1EED.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
+00EA 030C ; [.1EED.0023.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
+00CA 030C ; [.1EED.0023.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
+0065 0302 030C ; [.1EED.0023.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
+0045 0302 030C ; [.1EED.0023.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
+1EC1      ; [.1EED.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+0065 0302 0300 ; [.1EED.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+0065 0302 0340 ; [.1EED.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+1EC0      ; [.1EED.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+0045 0302 0300 ; [.1EED.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+0045 0302 0340 ; [.1EED.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+00EA 0300 ; [.1EED.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
+00EA 0340 ; [.1EED.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
+00CA 0300 ; [.1EED.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
+00CA 0340 ; [.1EED.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
+00EA      ; [.1EED.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
+0065 0302 ; [.1EED.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
+00CA      ; [.1EED.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+0045 0302 ; [.1EED.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+1EC5      ; [.1EED.0025.0002][.0000.002D.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
+1EC4      ; [.1EED.0025.0008][.0000.002D.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
+1EC3      ; [.1EED.0025.0002][.0000.003B.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
+1EC2      ; [.1EED.0025.0008][.0000.003B.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
+1EC7      ; [.1EED.0025.0002][.0000.0042.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
+1EC6      ; [.1EED.0025.0008][.0000.0042.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
+012B      ; [.1F75.001C.0002] # LATIN SMALL LETTER I WITH MACRON
+0069 0304 ; [.1F75.001C.0002] # LATIN SMALL LETTER I WITH MACRON
+012A      ; [.1F75.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
+0049 0304 ; [.1F75.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
+00ED      ; [.1F75.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+0069 0301 ; [.1F75.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+0069 0341 ; [.1F75.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+00CD      ; [.1F75.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+0049 0301 ; [.1F75.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+0049 0341 ; [.1F75.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+01D0      ; [.1F75.001E.0002] # LATIN SMALL LETTER I WITH CARON
+0069 030C ; [.1F75.001E.0002] # LATIN SMALL LETTER I WITH CARON
+01CF      ; [.1F75.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
+0049 030C ; [.1F75.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
+00EC      ; [.1F75.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+0069 0300 ; [.1F75.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+0069 0340 ; [.1F75.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+00CC      ; [.1F75.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+0049 0300 ; [.1F75.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+0049 0340 ; [.1F75.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+006D 0304 ; [.1FEE.001C.0002] # <LATIN SMALL LETTER M, COMBINING MACRON>
+004D 0304 ; [.1FEE.001C.0008] # <LATIN CAPITAL LETTER M, COMBINING MACRON>
+1E3F      ; [.1FEE.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+006D 0301 ; [.1FEE.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+006D 0341 ; [.1FEE.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+1E3E      ; [.1FEE.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+004D 0301 ; [.1FEE.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+004D 0341 ; [.1FEE.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+006D 030C ; [.1FEE.001E.0002] # <LATIN SMALL LETTER M, COMBINING CARON>
+004D 030C ; [.1FEE.001E.0008] # <LATIN CAPITAL LETTER M, COMBINING CARON>
+006D 0300 ; [.1FEE.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE ACCENT>
+006D 0340 ; [.1FEE.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE TONE MARK>
+004D 0300 ; [.1FEE.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE ACCENT>
+004D 0340 ; [.1FEE.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE TONE MARK>
+006E 0304 ; [.1FFD.001C.0002] # <LATIN SMALL LETTER N, COMBINING MACRON>
+004E 0304 ; [.1FFD.001C.0008] # <LATIN CAPITAL LETTER N, COMBINING MACRON>
+0144      ; [.1FFD.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+006E 0301 ; [.1FFD.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+006E 0341 ; [.1FFD.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+0143      ; [.1FFD.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+004E 0301 ; [.1FFD.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+004E 0341 ; [.1FFD.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+0148      ; [.1FFD.001E.0002] # LATIN SMALL LETTER N WITH CARON
+006E 030C ; [.1FFD.001E.0002] # LATIN SMALL LETTER N WITH CARON
+0147      ; [.1FFD.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
+004E 030C ; [.1FFD.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
+01F9      ; [.1FFD.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+006E 0300 ; [.1FFD.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+006E 0340 ; [.1FFD.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+01F8      ; [.1FFD.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+004E 0300 ; [.1FFD.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+004E 0340 ; [.1FFD.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+014D      ; [.2021.001C.0002] # LATIN SMALL LETTER O WITH MACRON
+006F 0304 ; [.2021.001C.0002] # LATIN SMALL LETTER O WITH MACRON
+014C      ; [.2021.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
+004F 0304 ; [.2021.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
+00F3      ; [.2021.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+006F 0301 ; [.2021.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+006F 0341 ; [.2021.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+00D3      ; [.2021.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+004F 0301 ; [.2021.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+004F 0341 ; [.2021.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+01D2      ; [.2021.001E.0002] # LATIN SMALL LETTER O WITH CARON
+006F 030C ; [.2021.001E.0002] # LATIN SMALL LETTER O WITH CARON
+01D1      ; [.2021.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
+004F 030C ; [.2021.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
+00F2      ; [.2021.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+006F 0300 ; [.2021.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+006F 0340 ; [.2021.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+00D2      ; [.2021.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+004F 0300 ; [.2021.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+004F 0340 ; [.2021.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+016B      ; [.20FA.001C.0002] # LATIN SMALL LETTER U WITH MACRON
+0075 0304 ; [.20FA.001C.0002] # LATIN SMALL LETTER U WITH MACRON
+016A      ; [.20FA.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
+0055 0304 ; [.20FA.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
+00FA      ; [.20FA.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+0075 0301 ; [.20FA.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+0075 0341 ; [.20FA.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+00DA      ; [.20FA.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+0055 0301 ; [.20FA.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+0055 0341 ; [.20FA.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+01D4      ; [.20FA.001E.0002] # LATIN SMALL LETTER U WITH CARON
+0075 030C ; [.20FA.001E.0002] # LATIN SMALL LETTER U WITH CARON
+01D3      ; [.20FA.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
+0055 030C ; [.20FA.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
+00F9      ; [.20FA.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+0075 0300 ; [.20FA.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+0075 0340 ; [.20FA.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+00D9      ; [.20FA.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+0055 0300 ; [.20FA.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+0055 0340 ; [.20FA.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+01D6      ; [.20FA.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
+0075 0308 0304 ; [.20FA.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
+01D5      ; [.20FA.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
+0055 0308 0304 ; [.20FA.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
+00FC 0304 ; [.20FA.0021.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING MACRON>
+00DC 0304 ; [.20FA.0021.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING MACRON>
+01D8      ; [.20FA.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+0075 0308 0301 ; [.20FA.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+0075 0308 0341 ; [.20FA.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+01D7      ; [.20FA.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+0055 0308 0301 ; [.20FA.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+0055 0308 0341 ; [.20FA.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+00FC 0301 ; [.20FA.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
+00FC 0341 ; [.20FA.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
+00DC 0301 ; [.20FA.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
+00DC 0341 ; [.20FA.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
+01DA      ; [.20FA.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
+0075 0308 030C ; [.20FA.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
+01D9      ; [.20FA.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
+0055 0308 030C ; [.20FA.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
+00FC 030C ; [.20FA.0023.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING CARON>
+00DC 030C ; [.20FA.0023.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING CARON>
+01DC      ; [.20FA.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+0075 0308 0300 ; [.20FA.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+0075 0308 0340 ; [.20FA.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+01DB      ; [.20FA.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+0055 0308 0300 ; [.20FA.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+0055 0308 0340 ; [.20FA.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+00FC 0300 ; [.20FA.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
+00FC 0340 ; [.20FA.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
+00DC 0300 ; [.20FA.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
+00DC 0340 ; [.20FA.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
+00FC      ; [.20FA.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
+0075 0308 ; [.20FA.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
+00DC      ; [.20FA.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
+0055 0308 ; [.20FA.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
 F967      ; [.804A.0020.0002] # CJK COMPATIBILITY IDEOGRAPH-F967
 FA70      ; [.82DE.0020.0002] # CJK COMPATIBILITY IDEOGRAPH-FA70
 F905      ; [.81CB.0020.0002] # CJK COMPATIBILITY IDEOGRAPH-F905
